braindecode.models.get_output_shape
===================================

.. currentmodule:: braindecode.models

.. autofunction:: get_output_shape

.. include:: braindecode.models.get_output_shape.examples

.. raw:: html

    <div style='clear:both'></div>